@@ -20,15 +20,14 @@ from .jvm.optimization import options
 # Hash outputs of all tests in order to easily detect changes between versions
 fullhash = b''
 
-for i in range(1, 7):
+for i in range(1, 8):
     name = 'test{}'.format(i)
     print(name)
     dir = os.path.join('tests', name)
     rawdex = read(os.path.join(dir, 'classes.dex'), 'rb')
 
     for opts in [options.NONE, options.PRETTY, options.ALL]:
-        classes, errors = translate(rawdex, opts=opts)
-        assert(not errors)
+        classes, errors = translate(rawdex, opts=opts, allowErrors=False)
 
         for cls in classes.values():
             print('{:08b}'.format(0), hashlib.sha256(cls).hexdigest())
